@@ -2,7 +2,7 @@ from datetime import datetime
 import json
 import uuid
 from pathlib import Path
-from typing import Optional, Dict
+from typing import Optional
 from machineconfig.utils.scheduler import Scheduler
 from machineconfig.cluster.sessions_managers.zellij_local import run_command_in_zellij_tab
 from machineconfig.cluster.sessions_managers.zellij_remote import ZellijRemoteLayoutGenerator
@@ -10,18 +10,24 @@ from machineconfig.utils.schemas.layouts.layout_types import LayoutConfig
 from machineconfig.logger import get_logger
 
 
-TMP_SERIALIAZATION_DIR = Path.home().joinpath("tmp_results", "session_manager", "zellij", "remote_manager")
 logger = get_logger("cluster.sessions_managers.zellij_remote_manager")
+TMP_SERIALIAZATION_DIR = Path.home() / "tmp_results" / "zellij_sessions" / "serialized"
 
 
 class ZellijSessionManager:
-    def __init__(self, machine_layouts: Dict[str, LayoutConfig], session_name_prefix: str):
+    def __init__(self, machine_layouts: dict[str, LayoutConfig], session_name_prefix: str):
         self.session_name_prefix = session_name_prefix
         self.machine_layouts = machine_layouts  # Store the original config
         self.managers: list[ZellijRemoteLayoutGenerator] = []
         for machine, layout_config in machine_layouts.items():
-            an_m = ZellijRemoteLayoutGenerator(remote_name=machine, session_name_prefix=self.session_name_prefix)
-            an_m.create_zellij_layout(layout_config=layout_config, output_dir=None)
+            from machineconfig.cluster.sessions_managers.zellij_utils.layout_generator import LayoutGenerator
+            session_name = f"{self.session_name_prefix}_{LayoutGenerator.generate_random_suffix(8)}"
+            an_m = ZellijRemoteLayoutGenerator(
+                layout_config=layout_config,
+                remote_name=machine,
+                session_name=session_name
+            )
+            an_m.create_layout_file()
             self.managers.append(an_m)
 
     def ssh_to_all_machines(self) -> str:
@@ -51,10 +57,7 @@ class ZellijSessionManager:
             if scheduler.cycle % 2 == 0:
                 statuses = []
                 for _idx, an_m in enumerate(self.managers):
-                    if not an_m.layout_config:
-                        a_status = {}
-                    else:
-                        a_status = an_m.process_monitor.check_all_commands_status(an_m.layout_config)
+                    a_status = an_m.process_monitor.check_all_commands_status(an_m.layout_config)
                     statuses.append(a_status)
                 keys = []
                 for item in statuses:
@@ -71,7 +74,7 @@ class ZellijSessionManager:
                 # Check if all stopped
                 running_count = sum(1 for item in status_data if item.get("status", {}).get("running", False))
                 if running_count == 0:  # they all stopped
-                    sched.max_cycles = sched.cycle  # stop the scheduler from calling this routine again
+                    scheduler.max_cycles = scheduler.cycle  # stop the scheduler from calling this routine again
 
                 # Print status
                 for item in status_data:
